.. pypims documentation master file, created by
   sphinx-quickstart on Sun Jun 28 22:59:12 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pypims's documentation
=================================

Pypims: Python APIs for `hipims-cuda <https://github.com/HEMLab/hipims>`_.


.. toctree::
   :caption: Table of Content:

   about
   quickstart

   Tutorials/index
   Modules/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

